@@ -1,12 +1,11 @@
+import attr
 from datetime import datetime
 from typing import Optional
 
-import attr
-
 
 @attr.dataclass(frozen=True, slots=True)
 class JenisPendaftaran:
-    jenis_pendaftaran_id: str
+    jenis_pendaftaran_id: int
     nama: str
     daftar_sekolah: str
     daftar_rombel: str
