@@ -6,7 +6,7 @@ import attr
 
 @attr.dataclass(frozen=True, slots=True)
 class KlasifikasiLembaga:
-    klasifikasi_lembaga_id: str
+    klasifikasi_lembaga_id: int
     nama: str
     create_date: datetime
     last_update: datetime
